@@ -80,7 +80,7 @@ def __check_alias__(
 # source.
 ALIAS = "syst3m"
 SOURCE_NAME = "syst3m"
-SOURCE_PATH= __get_source_path__(__file__, back=3)
+SOURCE_PATH, BASE = __get_source_path__(__file__, back=3)
 OS = __get_operating_system__()
 
 # imports.
